@@ -21,8 +21,6 @@
 #include <glibtop/netlist.h>
 #include <math.h>
 
-#include <libgnomevfs/gnome-vfs-utils.h>
-
 #include <algorithm>
 
 #include "procman.h"
@@ -320,8 +318,8 @@ namespace
     char* total_text;
     char* text;
 
-    used_text = SI_gnome_vfs_format_file_size_for_display(used);
-    total_text = SI_gnome_vfs_format_file_size_for_display(total);
+    used_text = procman::format_size(used);
+    total_text = procman::format_size(total);
     // xgettext: 540MiB (53 %) of 1.0 GiB
     text = g_strdup_printf(_("%s (%.1f %%) of %s"), used_text, 100.0 * percent, total_text);
     gtk_label_set_text(label, text);
@@ -386,7 +384,8 @@ net_scale (LoadGraph *g, unsigned din, unsigned dout)
 	const unsigned bak_max(new_max);
 
 	// round up to get some extra space
-	new_max = 11U * new_max / 10U;
+	// yes, it can overflow
+	new_max = 1.1 * new_max;
 	// make sure max is not 0 to avoid / 0
 	// default to 1 KiB
 	new_max = std::max(new_max, 1024U);
@@ -416,14 +415,15 @@ net_scale (LoadGraph *g, unsigned din, unsigned dout)
 
 	new_max = coef10 * (1UL << (base10 * 10));
 	procman_debug("bak %u new_max %u pow2 %u coef10 %u", bak_max, new_max, pow2, coef10);
-	g_assert(bak_max <= new_max);
 
-	if (new_max == g->net.max)
-		return;
+	if (bak_max > new_max) {
+	  procman_debug("overflow detected: bak=%u new=%u", bak_max, new_max);
+	  new_max = bak_max;
+	}
 
-	// if max has decreased but not so much, don't do anything
-	// to avoid rescaling
-	if ((8U * g->net.max / 10U) < new_max && new_max < g->net.max)
+	// if max is the same or has decreased but not so much, don't
+	// do anything to avoid rescaling
+	if ((0.8 * g->net.max) < new_max && new_max <= g->net.max)
 		return;
 
 	const float scale = 1.0f * g->net.max / new_max;
@@ -435,7 +435,7 @@ net_scale (LoadGraph *g, unsigned din, unsigned dout)
 		}
 	}
 
-	procman_debug("dmax = %u max = %u new_max = %u", dmax, g->net.max, new_max);
+	procman_debug("rescale dmax = %u max = %u new_max = %u", dmax, g->net.max, new_max);
 
 	g->net.max = new_max;
 
@@ -513,13 +513,13 @@ get_net (LoadGraph *g)
 
 	gtk_label_set_text (GTK_LABEL (g->labels.net_in), procman::format_rate(din).c_str());
 
-	text1 = SI_gnome_vfs_format_file_size_for_display (in);
+	text1 = procman::format_size (in);
 	gtk_label_set_text (GTK_LABEL (g->labels.net_in_total), text1);
 	g_free (text1);
 
 	gtk_label_set_text (GTK_LABEL (g->labels.net_out), procman::format_rate(dout).c_str());
 
-	text1 = SI_gnome_vfs_format_file_size_for_display (out);
+	text1 = procman::format_size (out);
 	gtk_label_set_text (GTK_LABEL (g->labels.net_out_total), text1);
 	g_free (text1);
 }
